# Rudder client

The official library for Realnaut Rudder tool. Realnaut Rudder tool backend consist of multiple Cloud Runs and this library contains the necessary code for these services to communicate with different APIs.
